@@ -9,12 +9,11 @@ while (Next==0){
 Result<-RSCABK(x.i.j.K,n.i.j,m.i,TestK,test.type=test.type)
 
 #The step down
-Next<- Result['P-Value']>0.05 | dim(x.i.j.K)[2]==2 #Stop conditions of too high of p.val or 2 treatments
-x.i.j.K<-x.i.j.K[ ,-dim(x.i.j.K)[2]]
-n.i.j<-n.i.j[ ,-dim(n.i.j)[2]]
-m.i<-m.i[-length(m.i)]
-Next<- Result['P-Value']>0.05 | length(x.i.j.K)>1
-
+	Next<- Result['P-Value']>0.05 | dim(x.i.j.K)[2]<=2 #Stop conditions of too high of p.val or 2 treatments
+	x.i.j.K<-x.i.j.K[ ,-dim(x.i.j.K)[2]]
+	n.i.j<-n.i.j[ ,-dim(n.i.j)[2]]
+	m.i<-m.i[-length(m.i)]
+	Result.K<-rbind(Result.K, as.data.frame(Result))
 }
 
 
